@@ -51,7 +51,7 @@ int main(int argc, char **argv)
     aboutData.addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
 
     app.setOrganizationDomain(QStringLiteral("kde.org"));
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("akonadi")));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
